OAuth2 CKAN extension  [![Build Status](https://build.conwet.fi.upm.es/jenkins/buildStatus/icon?job=ckan_oauth2)](https://build.conwet.fi.upm.es/jenkins/job/ckan_oauth2/)
=====================

The OAuth2 extension allows site visitors to login through an OAuth2 server.

**Note**: This extension has been tested in CKAN 2.2 and 2.3. It may not work in other versions.

**Note**: If you want to use the FIWARE IdM, use the code on `fiware-migration` branch. 


Links
-------------------------

1. [Activating & Installing the plugin](https://github.com/conwetlab/ckanext-oauth2/wiki/Activating-and-Installing)
2. [Starting CKAN over HTTPs](https://github.com/conwetlab/ckanext-oauth2/wiki/Starting-CKAN-over-HTTPs)
3. [How it works?](https://github.com/conwetlab/ckanext-oauth2/wiki/How-it-works%3F)
 
Credits
-------
Based on the idea proposed by [Etalab](https://github.com/etalab/ckanext-oauth2)
